@@ -33,7 +33,7 @@ typedef enum {
 	PANEL_ORIENTATION_TOP    = 1 << 0,
 	PANEL_ORIENTATION_RIGHT  = 1 << 1,
 	PANEL_ORIENTATION_BOTTOM = 1 << 2,
-	PANEL_ORIENTATION_LEFT   = 1 << 3,
+	PANEL_ORIENTATION_LEFT   = 1 << 3
 } PanelOrientation;
 
 #define PANEL_HORIZONTAL_MASK (PANEL_ORIENTATION_TOP  | PANEL_ORIENTATION_BOTTOM)
@@ -53,13 +53,13 @@ typedef enum {
 	PANEL_STATE_HIDDEN_UP    = 2,
 	PANEL_STATE_HIDDEN_DOWN  = 3,
 	PANEL_STATE_HIDDEN_LEFT  = 4,
-	PANEL_STATE_HIDDEN_RIGHT = 5,
+	PANEL_STATE_HIDDEN_RIGHT = 5
 } PanelState;
 
 typedef enum {
 	PANEL_ANIMATION_SLOW   = 0,
 	PANEL_ANIMATION_MEDIUM = 1,
-	PANEL_ANIMATION_FAST   = 2,
+	PANEL_ANIMATION_FAST   = 2
 } PanelAnimationSpeed;
 
 typedef enum {
