@@ -24,7 +24,7 @@
 #include "panel-profile.h"
 #include "panel-lockdown.h"
 
-#define MOVE_INCREMENT 2
+#define MOVE_INCREMENT 1
 
 typedef enum {
 	PANEL_SWITCH_MOVE = 0,
@@ -2361,9 +2361,9 @@ bind_top_applet_events (GtkWidget *widget)
 			  NULL);
 
 	/* connect-after so that we stop the propogation of the event */
-	g_signal_connect_after (widget, "button-press-event",
-				G_CALLBACK (panel_widget_applet_button_press_event),
-				NULL);
+	g_signal_connect (widget, "button-press-event",
+			  G_CALLBACK (panel_widget_applet_button_press_event),
+			  NULL);
 
 	g_signal_connect (widget, "button-release-event",
 			  G_CALLBACK (panel_widget_applet_button_release_event),
@@ -2918,7 +2918,7 @@ panel_widget_toggle_applet_locked (PanelWidget *panel,
 }
 
 gboolean
-panel_applet_is_in_drag ()
+panel_applet_is_in_drag (void)
 {
 	return panel_applet_in_drag;
 }
